clear all
close all
clc
labelsize=14;
% Range and azimuth coordinates
load row;
load col;
% Two-way Antenna pattern
load H; 
figure
plot(row,H1)
title('Two-way Antenna pattern')
hold on
plot([-9 9],[0.5 0.5],'--k')
hold on
plot([-1.5 -1.5],[0 0.5],'--k')
hold on
plot([1.5 1.5],[0 0.5],'--k')
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Normalized amplitude','fontsize',labelsize);
set(gca,'FontSize',labelsize);
set(gca,'ytick',[0,0.5,1])
set(gca,'xtick',[-9:3:9])
axis([-9 9 0 1])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Scenario
Sigma1=double(imread('scenario.bmp'));
Sigma1=imresize(Sigma1,[200 200]);
Sigma1=Sigma1(21:end, :);
% Sigma1=imresize(Sigma1,[298 1200]);
Sigma1=flipud(Sigma1);
% Sigma1(1:60,1:150)=0.3*Sigma1(1:60,1:150);
% Sigma1=zeros(200,200);
figure
imagesc(Sigma1)
axis xy
colormap(jet)
xlabel('Azimuth (samples)','fontsize',labelsize);
ylabel('Range (samples)','fontsize',labelsize);
set(gca,'FontSize',labelsize);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Raw echo
load Sn;
figure
imagesc(abs(Sn))
axis xy
colormap(jet)
xlabel('Azimuth (samples)','fontsize',labelsize);
ylabel('Range (samples)','fontsize',labelsize);
set(gca,'FontSize',labelsize);
%%%%%%%%%%%%%%%%%%%%%%%%%%  Real beam after matched filtering
load Snew;
figure
imagesc(row,col,abs(Snew))
axis xy
colormap(jet)
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Range (degree)','fontsize',labelsize);
set(gca,'FontSize',labelsize);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Normalized
Snew1=Snew;
Snew1=Snew1/max(max(Snew1));
H=H1(375:826);
%%%%%%%%%%%%%%%%%
tic
[rIAA]=deconvIAAf(abs(Snew1),H,1e-3,0.1);
toc
rIAA=rIAA/max(max(rIAA));
figure
imagesc(row,col,abs(rIAA))
axis xy
colormap(jet)
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Range (meter)','fontsize',labelsize);
set(gca,'FontSize',labelsize);
%%%%%%%%%%%%%%%%%

tic
[rSLIM]=deconvSLIMf(abs(Snew1),H,0.1,1e-3);
toc
rSLIM=rSLIM/max(max(rSLIM));
figure
imagesc(row,col,abs(rSLIM))
axis xy
colormap(jet)
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Range (meter)','fontsize',labelsize);
set(gca,'FontSize',labelsize);

%%%%%%%%%%%%%%%%%%%%%%%%%

tic
[rSPICE]=SPICEdeconvf(abs(Snew1),H,1,1e-3,0.1);
toc
rSPICE=rSPICE/max(max(rSPICE));
figure
imagesc(row,col,abs(rSPICE))
axis xy
colormap(jet)
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Range (meter)','fontsize',labelsize);
set(gca,'FontSize',labelsize);
%%%%%%%%%%%%%%%%%

tic
[rqSPICE]=SPICEdeconvf(abs(Snew1),H,1.7,1e-3,0.1);
toc
rqSPICE=rqSPICE/max(max(rqSPICE));
figure
imagesc(row,col,abs(rqSPICE))
axis xy
colormap(jet)
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Range (meter)','fontsize',labelsize);
set(gca,'FontSize',labelsize);

tic
[rqSPICEw]=BandSPICEdeconvf(abs(Snew1),H,1.7,1e-3,0.1,30);
toc
rqSPICEw=rqSPICEw/max(max(rqSPICEw));
figure
imagesc(row,col,abs(rqSPICEw))
axis xy
colormap(jet)
xlabel('Azimuth (degree)','fontsize',labelsize);
ylabel('Range (meter)','fontsize',labelsize);
set(gca,'FontSize',labelsize);
% %%%%%%%%%%%%%%%%%%%%%%
[M,N]=size(Snew);
ll=162;
Scenario=imresize(Sigma1,[M,N]);
ss=Scenario(ll,:);
ss=ss/max(ss);
y=Snew1(ll,:);
y1=rIAA(ll,:);
y2=rSLIM(ll,:);
y3=rSPICE(ll,:);
y4=rqSPICE(ll,:);
y5=rqSPICEw(ll,:);
y1=y1/max(y1);
y2=y2/max(y2);
y3=y3/max(y3);
y4=y4/max(y4);
y5=y5/max(y5);
%%%%%%%%%%%%%
figure
plot(y4)
%%%%%%%%%%%%%%
y=y/max(y);
figure
h1=plot(row,db(abs(y)),'k-','markersize',3,'linewidth',1.2);
hold on
h4=plot(row,db(abs(y3)),'r->','markersize',3,'linewidth',1.2);
hold on
h5=plot(row,db(abs(y4)),'c-x','markersize',3,'linewidth',1.2);
hold on
h5=plot(row,db(abs(y5)),'b-<','markersize',3,'linewidth',1.2);
hold on
h6=plot(row,db(abs(ss)),'-*','color',[0.5 0.2 0.5],'markersize',3,'linewidth',1.2);
axis([-9,9,-40,20])
legend('Noisy measurement','SPICE','q-SPICE','Wideband q-SPICE','Truth')
set(gca,'FontSize',10);
xlabel('Azimtuh (degree)','fontsize',10);
ylabel('Normalized Amplitude (dB)','fontsize',10);
set(gca,'ytick',[-50:10:20])
% hleg1 = legend('Noisy measurement','REGU','TSVD','Wiener inverse filtering','IAA','TR-IAA','Truth');
%%%%%%%%%   IAA
figure
h1=plot(row,db(abs(y)),'k-','markersize',3,'linewidth',1.2);
hold on
h2=plot(row,db(abs(y1)),'r->','markersize',3,'linewidth',1.2);
hold on
h3=plot(row,db(abs(y2)),'c-x','markersize',3,'linewidth',1.2);
hold on
h6=plot(row,db(abs(ss)),'-*','color',[0.5 0.2 0.5],'markersize',3,'linewidth',1.2);
axis([-9,9,-40,20])
legend('Noisy measurement','IAA','SLIM','Truth')
set(gca,'FontSize',10);
xlabel('Azimtuh (degree)','fontsize',10);
ylabel('Normalized Amplitude (dB)','fontsize',10);
set(gca,'ytick',[-50:10:20])